@@ -69,8 +69,8 @@ AltTabPopupW.prototype = {
     __proto__ : AltTab.AltTabPopup.prototype,
 
     show : function(backward, switch_group) {
-        let appSys = Shell.AppSystem.get_default();
-        let apps = appSys.get_running ();
+        let tracker = Shell.WindowTracker.get_default();
+        let apps = tracker.get_running_apps ('');
 
         if (!apps.length)
             return false;
@@ -358,8 +358,8 @@ AltTabPopup2.prototype = {
 	let list = '';
 	let normal_windows= [];
 	let appIcons = [];
-	let appSys = Shell.AppSystem.get_default();
-	let apps = appSys.get_running();
+	let tracker = Shell.WindowTracker.get_default();
+	let apps = tracker.get_running_apps ('');
 
 	for (let w = windows.length-1; w >= 0; w--) {
 	    let win = windows[w].get_meta_window();
@@ -507,8 +507,8 @@ WindowList.prototype = {
 
 	    let win=windows[w];
 
-	    let appSys = Shell.AppSystem.get_default();
-	    let apps = appSys.get_running();
+	    let tracker = Shell.WindowTracker.get_default();
+	    let apps = tracker.get_running_apps ('');
 	    let ap1 = null;
 	    for (let i = 0; i < apps.length; i++) {
 	        let app_wins = apps[i].get_windows();
