@@ -68,8 +68,8 @@ DriveMenu.prototype = {
 	this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
 	this.menu.addAction(_("Open file manager"), function(event) {
 	    let appSystem = Shell.AppSystem.get_default();
-	    let app = appSystem.get_app('nautilus.desktop');
-	    app.activate(-1);
+	    let app = appSystem.lookup_app('nautilus.desktop');
+	    app.activate_full(-1, event.get_time());
 	});
     },
 
@@ -90,9 +90,17 @@ DriveMenu.prototype = {
 }
 
 // Put your extension initialization code here
-function main(metadata) {
+function init(metadata) {
     imports.gettext.bindtextdomain('gnome-shell-extensions', metadata.localedir);
+}
 
-    Panel.STANDARD_TRAY_ICON_ORDER.unshift('drive-menu');
-    Panel.STANDARD_TRAY_ICON_SHELL_IMPLEMENTATION['drive-menu'] = DriveMenu;
+let _indicator;
+
+function enable() {
+    _indicator = new DriveMenu;
+    Main.panel.addToStatusArea('drive-menu', _indicator);
+}
+
+function disable() {
+    _indicator.destroy();
 }
